==> spip_4.0.4.orig.tar.xz: plugins-dist/revisions/lang/revisions_pt.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/revisions?lang_cible=pt
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_comparer' => 'Ver as diferenças',

	// D
	'diff_para_ajoute' => 'Parágrafo acrescentado',
	'diff_para_deplace' => 'Parágrafo movido',
	'diff_para_supprime' => 'Parágrafo eliminado',
	'diff_texte_ajoute' => 'Texto acrescentado',
	'diff_texte_deplace' => 'Texto movido',
	'diff_texte_supprime' => 'Texto suprimido',
	'differences_versions' => 'Diferenças entre a versão N<sup>o</sup>@id_version@ e a versão N<sup>o</sup>@id_diff@',

	// I
	'icone_restaurer_version' => 'Restaurar a versão N<sup>o</sup>@version@',
	'icone_suivi_revisions' => 'Seguimento das revisões',
	'info_1_revision' => '1 revisão',
	'info_aucune_revision' => 'Sem revisões',
	'info_historique' => 'Revisões :',
	'info_historique_lien' => 'Visualizar o histórico de alterações',
	'info_historique_titre' => 'Acompanhamento das revisões',
	'info_nb_revisions' => '@nb@ revisões',

	// L
	'label_choisir_id_version' => 'Seleccione as versões a comparar',
	'label_config_revisions_objets' => 'Activar as revisões para os objectos :',

	// M
	'message_valider_recuperer_version' => 'Valide o formulário para regressar a esta versão.',

	// O
	'objet_editorial' => 'objecto',

	// P
	'plugin_update' => 'Actualização do plugin "Révisions" na versão @version@.',

	// T
	'titre_form_revisions_objets' => 'Activar as revisões',
	'titre_restaurer_version' => 'Restaurar uma versão',
	'titre_revisions' => 'Revisões',

	// V
	'version_deplace_rubrique' => 'Movido de <b>« @from@ »</b> vers <b>« @to@ »</b>.',
	'version_initiale' => 'versão inicial',
	'voir_differences' => 'Ver as diferenças',
	'voir_mes_revisions' => 'As minhas revisões',
	'voir_revisions' => 'Mostrar as revisões (@objet@ @id_objet@ : @titre@)',
	'voir_toutes_les_revisions' => 'Todas as revisões'
);

==> spip_4.4.9+dfsg.orig.tar.xz: plugins-dist/revisions/lang/revisions_pt.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/revisions?lang_cible=pt
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_comparer' => 'Ver as diferenças',

	// D
	'diff_para_ajoute' => 'Parágrafo acrescentado',
	'diff_para_deplace' => 'Parágrafo movido',
	'diff_para_supprime' => 'Parágrafo eliminado',
	'diff_texte_ajoute' => 'Texto acrescentado',
	'diff_texte_deplace' => 'Texto movido',
	'diff_texte_supprime' => 'Texto suprimido',
	'differences_versions' => 'Diferenças entre a versão N<sup>o</sup>@id_version@ e a versão N<sup>o</sup>@id_diff@',

	// I
	'icone_restaurer_version' => 'Restaurar a versão N<sup>o</sup>@version@',
	'icone_suivi_revisions' => 'Seguimento das revisões',
	'info_1_revision' => '1 revisão',
	'info_aucune_revision' => 'Sem revisões',
	'info_historique' => 'Revisões :',
	'info_historique_lien' => 'Visualizar o histórico de alterações',
	'info_historique_titre' => 'Acompanhamento das revisões',
	'info_nb_revisions' => '@nb@ revisões',

	// L
	'label_choisir_id_version' => 'Seleccione as versões a comparar',
	'label_config_revisions_objets' => 'Activar as revisões para os objectos :',

	// M
	'message_valider_recuperer_version' => 'Valide o formulário para regressar a esta versão.',

	// O
	'objet_editorial' => 'objecto',

	// P
	'plugin_update' => 'Actualização do plugin "Révisions" na versão @version@.',

	// T
	'titre_form_revisions_objets' => 'Activar as revisões',
	'titre_restaurer_version' => 'Restaurar uma versão',
	'titre_revisions' => 'Revisões',

	// V
	'version_deplace_rubrique' => 'Movido de <b>« @from@ »</b> vers <b>« @to@ »</b>.',
	'version_initiale' => 'versão inicial',
	'voir_differences' => 'Ver as diferenças',
	'voir_mes_revisions' => 'As minhas revisões',
	'voir_revisions' => 'Mostrar as revisões (@objet@ @id_objet@ : @titre@)',
	'voir_toutes_les_revisions' => 'Todas as revisões',
];
